import { 
  geoPath, 
  geoVanDerGrinten4,
  zoom,
  event
} from 'd3';

const projection = geoVanDerGrinten4()
const pathGenerator = geoPath().projection(projection)

export const choroplethMap = (selection, props ) => {
  const { 
    features,
    colorScale,
    colorValue,
    selectColorValue
  } = props
  
  const gUpdate = selection.selectAll('g').data([null])
  const gEnter = gUpdate.enter().append('g')
  const g = gUpdate.merge(gEnter)
  
gEnter.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({ type: 'Sphere' }))
.merge(gUpdate.select('.sphere'))
	.attr('fill', d => 
        !selectColorValue 
          ? "#3a539b"
          : "black"
  )
  .attr('opacity', selectColorValue ? 0.9 : 1)

  
  
  selection.call(zoom().on('zoom', () => {
    g.attr('transform', event.transform)
  }))

  
  
  const countryPaths = g.selectAll('.country')
  	.data(features)
  
  const countryPathsEnter = countryPaths
    .enter().append('path')
      .attr('class', 'country')


  
  countryPaths
		.merge(countryPathsEnter)
    	.attr('d', pathGenerator)
  		.attr('fill', d => colorScale(colorValue(d)))
  		.attr('opacity', d => 
        !selectColorValue  || selectColorValue === colorValue(d)
          ? 1
          : 0.2
    )
  
  countryPathsEnter.append('title')
      .text(d => d.properties.name + ': ' + colorValue(d))
}